@@ -43,7 +43,7 @@ class HttpClient(object):
     def __init__(self, host, port=None, protocol="https", max_retries=3,
                  timeout=AXAPI_DEFAULT_REQ_TIMEOUT):
         if port is None:
-            if protocol is 'http':
+            if protocol == 'http':
                 self.port = 80
             else:
                 self.port = 443
