@@ -13,8 +13,6 @@
 #    under the License.
 from __future__ import absolute_import
 from __future__ import unicode_literals
-import six
-
 
 from acos_client import errors as acos_errors
 from acos_client.v30 import base
@@ -67,15 +65,15 @@ class HealthMonitor(base.BaseV30):
     def get(self, name, **kwargs):
         return self._get(self.url_prefix + name, **kwargs)
 
-    def _set(self, action, name, mon_method, interval, timeout, max_retries,
-             method=None, url=None, expect_code=None, port=None, ipv4=None, update=False,
+    def _set(self, name, mon_method, hm_interval, hm_timeout, hm_max_retries,
+             method=None, url=None, expect_code=None, port=None, ipv4=None, post_data=None,
              **kwargs):
         params = {
             "monitor": {
                 "name": name,
-                "retry": int(max_retries),
-                "interval": int(interval),
-                "timeout": int(timeout),
+                "retry": int(hm_max_retries),
+                "interval": int(hm_interval),
+                "timeout": int(hm_timeout),
                 "method": {
                     mon_method: self._method_objects[mon_method]
                 },
@@ -96,21 +94,29 @@ class HealthMonitor(base.BaseV30):
                 k = '%s-port' % mon_method
             params['monitor']['method'][mon_method][k] = int(port)
             params['monitor']['override-port'] = int(port)
+        # handle POST case for HTTP/HTTPS hm
+        if ('url-type' in params['monitor']['method'][mon_method] and
+                'url-path' in params['monitor']['method'][mon_method] and
+                params['monitor']['method'][mon_method]['url-type'] == "POST"):
+            if post_data:
+                params['monitor']['method'][mon_method]['post-type'] = "postdata"
+                if mon_method == self.HTTPS:
+                    params['monitor']['method'][mon_method]['https-postdata'] = str(post_data)
+                else:
+                    params['monitor']['method'][mon_method]['http-postdata'] = str(post_data)
+                postpath = params['monitor']['method'][mon_method]['url-path']
+                params['monitor']['method'][mon_method]['post-path'] = postpath
+                params['monitor']['method'][mon_method].pop('url-path', None)
+        else:
+            params['monitor']['method'][mon_method].pop('post-type', None)
+            params['monitor']['method'][mon_method].pop('http-postdata', None)
+            params['monitor']['method'][mon_method].pop('post-path', None)
 
-        # TODO(mdurrant) : Might have to get tricky with JSON structures
-        # ... due to 'mon_method' stuff.
-        config_defaults = kwargs.get("config_defaults")
+        return params
 
-        if config_defaults:
-            for k, v in six.iteritems(config_defaults):
-                params['monitor'][k] = v
-
-        if update:
-            action += name
-        return self._post(action, params, **kwargs)
-
-    def create(self, name, mon_type, interval, timeout, max_retries,
-               method=None, url=None, expect_code=None, port=None, ipv4=None, **kwargs):
+    def create(self, name, mon_type, hm_interval, hm_timeout, hm_max_retries,
+               method=None, url=None, expect_code=None, port=None, ipv4=None, post_data=None,
+               max_retries=None, timeout=None, **kwargs):
         try:
             self.get(name)
         except acos_errors.NotFound:
@@ -118,16 +124,21 @@ class HealthMonitor(base.BaseV30):
         else:
             raise acos_errors.Exists()
 
-        return self._set(self.url_prefix, name, mon_type, interval, timeout,
-                         max_retries, method, url, expect_code, port, ipv4, update=False,
-                         **kwargs)
+        params = self._set(name, mon_type, hm_interval, hm_timeout,
+                           hm_max_retries, method, url, expect_code, port, ipv4,
+                           post_data=post_data, **kwargs)
+        return self._post(self.url_prefix, params, max_retries=max_retries, timeout=timeout,
+                          axapi_args=kwargs)
 
-    def update(self, name, mon_type, interval, timeout, max_retries,
-               method=None, url=None, expect_code=None, port=None, ipv4=None, **kwargs):
+    def update(self, name, mon_type, hm_interval, hm_timeout, hm_max_retries,
+               method=None, url=None, expect_code=None, port=None, ipv4=None, post_data=None,
+               max_retries=None, timeout=None, **kwargs):
         self.get(name)  # We want a NotFound if it does not exist
-        return self._set(self.url_prefix, name, mon_type, interval, timeout,
-                         max_retries, method, url, expect_code, port, ipv4, update=True,
-                         **kwargs)
+        params = self._set(name, mon_type, hm_interval, hm_timeout,
+                           hm_max_retries, method, url, expect_code, port, ipv4,
+                           post_data=post_data, **kwargs)
+        return self._post(self.url_prefix + name, params, max_retries=max_retries, timeout=timeout,
+                          axapi_args=kwargs)
 
     def delete(self, name):
         return self._delete(self.url_prefix + name)
