@@ -13,8 +13,6 @@
 #    under the License.
 from __future__ import absolute_import
 from __future__ import unicode_literals
-import six
-
 
 from acos_client import errors as ae
 from acos_client.v30 import base
@@ -56,15 +54,18 @@ class VirtualPort(base.BaseV30):
     url_server_tmpl = '/slb/virtual-server/{name}/port/'
     url_port_tmpl = '{port_number}+{protocol}'
 
+    def format_vport_url(self, port_number, protocol):
+        if protocol == 'TERMINATED_HTTPS':
+            protocol = "https"
+        return self.url_port_tmpl.format(port_number=port_number, protocol=protocol)
+
     def all(self, virtual_server_name, **kwargs):
         url = self.url_server_tmpl.format(name=virtual_server_name)
         return self._get(url, **kwargs)
 
     def get(self, virtual_server_name, name, protocol, port):
         url = self.url_server_tmpl.format(name=virtual_server_name)
-        url += self.url_port_tmpl.format(
-            port_number=port, protocol=protocol
-        )
+        url += self.format_vport_url(port_number=port, protocol=protocol)
         return self._get(url)
 
     def _set(
@@ -72,7 +73,7 @@ class VirtualPort(base.BaseV30):
         virtual_server_name,
         name,
         protocol,
-        port,
+        protocol_port,
         service_group_name,
         s_pers_name=None,
         c_pers_name=None,
@@ -89,6 +90,10 @@ class VirtualPort(base.BaseV30):
         udp_template=None,
         exclude_minimize=None,
         update=False,
+        template_server_ssl=None,
+        template_client_ssl=None,
+        sampling_enable=None,
+        aflex_scripts=None,
         **kwargs
     ):
         exclude_minimize = [] if exclude_minimize is None else exclude_minimize
@@ -97,7 +102,7 @@ class VirtualPort(base.BaseV30):
                 "name": name,
                 "service-group": service_group_name,
                 "protocol": protocol,
-                "port-number": int(port),
+                "port-number": int(protocol_port),
                 "template-persist-source-ip": s_pers_name,
                 "template-persist-cookie": c_pers_name,
                 "extended-stats": status
@@ -146,40 +151,29 @@ class VirtualPort(base.BaseV30):
         if udp_template:
             params['port']['udp_template'] = udp_template
 
-        server_ssl_tmpl = kwargs.get("template_server_ssl", None)
-        client_ssl_tmpl = kwargs.get("template_client_ssl")
-        vport_defaults = kwargs.get("vport_defaults")
+        if template_server_ssl:
+            params['port']['template-server-ssl'] = template_server_ssl
+        if template_client_ssl:
+            params['port']['template-client-ssl'] = template_client_ssl
 
-        if vport_defaults:
-            for k, v in six.iteritems(vport_defaults):
-                params['port'][k] = v
-
-        if server_ssl_tmpl:
-            params['port']['template-server-ssl'] = server_ssl_tmpl
-        if client_ssl_tmpl:
-            params['port']['template-client-ssl'] = client_ssl_tmpl
-
-        sampling_enable = kwargs.get('sampling_enable')
         if sampling_enable is not None:
             self._set_sampling_enable(sampling_enable, params)
 
         if no_dest_nat is not None:
             params["port"]["no-dest-nat"] = 1 if no_dest_nat else 0
         if ha_conn_mirror is not None:
-            params["port"]["ha-conn-mirror"] = 1 if ha_conn_mirror else 0
+            if (protocol == self.TCP or protocol == self.UDP):
+                params["port"]["ha-conn-mirror"] = 1 if ha_conn_mirror else 0
         if conn_limit is not None:
             params["port"]["conn-limit"] = conn_limit
 
         url = self.url_server_tmpl.format(name=virtual_server_name)
 
-        aflex_scripts = kwargs.get("aflex-scripts", None)
         if aflex_scripts is not None:
             params['port']['aflex-scripts'] = aflex_scripts
 
         if update:
-            url += self.url_port_tmpl.format(
-                port_number=port, protocol=protocol
-            )
+            url += self.format_vport_url(port_number=protocol_port, protocol=protocol)
         return url, params, kwargs
 
     def create(
@@ -187,7 +181,7 @@ class VirtualPort(base.BaseV30):
         virtual_server_name,
         name,
         protocol,
-        port,
+        protocol_port,
         service_group_name,
         s_pers_name=None,
         c_pers_name=None,
@@ -202,14 +196,24 @@ class VirtualPort(base.BaseV30):
         virtual_port_templates=None,
         tcp_template=None,
         udp_template=None,
+        max_retries=None,
+        timeout=None,
+        template_server_ssl=None,
+        template_client_ssl=None,
+        sampling_enable=None,
+        aflex_scripts=None,
         **kwargs
     ):
 
+        # backward compatiable for a10-neutron-lbaas
+        if aflex_scripts is None and 'aflex-scripts' in kwargs:
+            aflex_scripts = kwargs.pop('aflex-scripts')
+
         url, params, kwargs = self._set(
             virtual_server_name,
             name,
             protocol,
-            port,
+            protocol_port,
             service_group_name,
             s_pers_name,
             c_pers_name,
@@ -224,17 +228,21 @@ class VirtualPort(base.BaseV30):
             virtual_port_templates=virtual_port_templates,
             tcp_template=tcp_template,
             udp_template=udp_template,
+            template_server_ssl=template_server_ssl,
+            template_client_ssl=template_client_ssl,
+            sampling_enable=sampling_enable,
+            aflex_scripts=aflex_scripts,
             **kwargs
         )
 
-        return self._post(url, params, **kwargs)
+        return self._post(url, params, max_retries=max_retries, timeout=timeout, axapi_args=kwargs)
 
     def _update(
         self,
         virtual_server_name,
         name,
         protocol,
-        port,
+        protocol_port,
         service_group_name,
         s_pers_name=None,
         c_pers_name=None,
@@ -249,10 +257,14 @@ class VirtualPort(base.BaseV30):
         virtual_port_templates=None,
         tcp_template=None,
         udp_template=None,
+        template_server_ssl=None,
+        template_client_ssl=None,
+        sampling_enable=None,
+        aflex_scripts=None,
         **kwargs
     ):
 
-        vp = self.get(virtual_server_name, name, protocol, port)
+        vp = self.get(virtual_server_name, name, protocol, protocol_port)
         if vp is None:
             raise ae.NotFound()
 
@@ -263,7 +275,7 @@ class VirtualPort(base.BaseV30):
                 virtual_server_name,
                 name,
                 protocol,
-                port,
+                protocol_port,
                 service_group_name,
                 s_pers_name,
                 c_pers_name,
@@ -280,6 +292,10 @@ class VirtualPort(base.BaseV30):
                 udp_template=udp_template,
                 exclude_minimize=exclude,
                 update=True,
+                template_server_ssl=template_server_ssl,
+                template_client_ssl=template_client_ssl,
+                sampling_enable=sampling_enable,
+                aflex_scripts=aflex_scripts,
                 **kwargs
             )
         except ae.AxapiJsonFormatError:
@@ -287,7 +303,7 @@ class VirtualPort(base.BaseV30):
                 virtual_server_name,
                 name,
                 protocol,
-                port,
+                protocol_port,
                 service_group_name,
                 s_pers_name,
                 c_pers_name,
@@ -304,6 +320,10 @@ class VirtualPort(base.BaseV30):
                 udp_template=udp_template,
                 exclude_minimize=exclude,
                 update=True,
+                template_server_ssl=template_server_ssl,
+                template_client_ssl=template_client_ssl,
+                sampling_enable=sampling_enable,
+                aflex_scripts=aflex_scripts,
                 **kwargs
             )
         return url, params, kwargs
@@ -313,7 +333,7 @@ class VirtualPort(base.BaseV30):
         virtual_server_name,
         name,
         protocol,
-        port,
+        protocol_port,
         service_group_name,
         s_pers_name=None,
         c_pers_name=None,
@@ -328,14 +348,24 @@ class VirtualPort(base.BaseV30):
         virtual_port_templates=None,
         tcp_template=None,
         udp_template=None,
+        max_retries=None,
+        timeout=None,
+        template_server_ssl=None,
+        template_client_ssl=None,
+        sampling_enable=None,
+        aflex_scripts=None,
         **kwargs
     ):
 
+        # backward compatiable for a10-neutron-lbaas
+        if aflex_scripts is None and 'aflex-scripts' in kwargs:
+            aflex_scripts = kwargs.pop('aflex-scripts')
+
         url, params, kwargs = self._update(
             virtual_server_name,
             name,
             protocol,
-            port,
+            protocol_port,
             service_group_name,
             s_pers_name=s_pers_name,
             c_pers_name=c_pers_name,
@@ -350,15 +380,19 @@ class VirtualPort(base.BaseV30):
             virtual_port_templates=virtual_port_templates,
             tcp_template=tcp_template,
             udp_template=udp_template,
+            template_server_ssl=template_server_ssl,
+            template_client_ssl=template_client_ssl,
+            sampling_enable=sampling_enable,
+            aflex_scripts=aflex_scripts,
             **kwargs)
-        return self._post(url, params, **kwargs)
+        return self._post(url, params, max_retries=max_retries, timeout=timeout, axapi_args=kwargs)
 
     def replace(
         self,
         virtual_server_name,
         name,
         protocol,
-        port,
+        protocol_port,
         service_group_name,
         s_pers_name=None,
         c_pers_name=None,
@@ -373,14 +407,24 @@ class VirtualPort(base.BaseV30):
         virtual_port_templates=None,
         tcp_template=None,
         udp_template=None,
+        max_retries=None,
+        timeout=None,
+        template_server_ssl=None,
+        template_client_ssl=None,
+        sampling_enable=None,
+        aflex_scripts=None,
         **kwargs
     ):
 
+        # backward compatiable for a10-neutron-lbaas
+        if aflex_scripts is None and 'aflex-scripts' in kwargs:
+            aflex_scripts = kwargs.pop('aflex-scripts')
+
         url, params, kwargs = self._update(
             virtual_server_name,
             name,
             protocol,
-            port,
+            protocol_port,
             service_group_name,
             s_pers_name=s_pers_name,
             c_pers_name=c_pers_name,
@@ -395,12 +439,16 @@ class VirtualPort(base.BaseV30):
             virtual_port_templates=virtual_port_templates,
             tcp_template=tcp_template,
             udp_template=udp_template,
+            template_server_ssl=template_server_ssl,
+            template_client_ssl=template_client_ssl,
+            sampling_enable=sampling_enable,
+            aflex_scripts=aflex_scripts,
             **kwargs)
-        return self._put(url, params, **kwargs)
+        return self._put(url, params, max_retries=max_retries, timeout=timeout, axapi_args=kwargs)
 
     def delete(self, virtual_server_name, name, protocol, port):
         url = self.url_server_tmpl.format(name=virtual_server_name)
-        url += self.url_port_tmpl.format(port_number=port, protocol=protocol)
+        url += self.format_vport_url(port_number=port, protocol=protocol)
         return self._delete(url)
 
     def _set_sampling_enable(self, sample_list, dest_obj):
