@@ -13,10 +13,7 @@
 #    under the License.
 from __future__ import absolute_import
 from __future__ import unicode_literals
-import six
 
-
-from acos_client import errors as acos_errors
 from acos_client.v30 import base
 from acos_client.v30.slb.virtual_port import VirtualPort
 
@@ -35,13 +32,15 @@ class VirtualServer(base.BaseV30):
         return self._get(self.url_prefix + name)
 
     def _set(self, name, ip_address=None, arp_disable=False, description=None, vrid=None,
-             virtual_server_templates=None, template_virtual_server=None, update=False, **kwargs):
+             virtual_server_templates=None, template_virtual_server=None,
+             port_list=None, status=None, **kwargs):
         params = {
             "virtual-server": self.minimal_dict({
                 "name": name,
                 "ip-address": ip_address,
                 "arp-disable": None if arp_disable is None else int(arp_disable),
-                "description": description
+                "description": description,
+                "port-list": port_list
             }),
         }
         if self._is_ipv6(ip_address):
@@ -51,6 +50,9 @@ class VirtualServer(base.BaseV30):
 
         if description:
             params['virtual-server']['description'] = description
+        else:
+            params['virtual-server']['description'] = None
+
         if vrid:
             params['virtual-server']['vrid'] = int(vrid)
         if virtual_server_templates:
@@ -65,39 +67,46 @@ class VirtualServer(base.BaseV30):
         if template_virtual_server:
             params['virtual-server']['template-virtual-server'] = str(template_virtual_server)
 
-        config_defaults = kwargs.get("config_defaults")
-        if config_defaults:
-            for k, v in six.iteritems(config_defaults):
-                params['virtual-server'][k] = v
-
-        if not update:
-            name = ''
-        return self._post(self.url_prefix + name, params, **kwargs)
+        return params
 
     def create(self, name, ip_address, arp_disable=False, description=None, vrid=None,
-               virtual_server_templates=None, template_virtual_server=None, **kwargs):
-        try:
-            self.get(name)
-        except acos_errors.NotFound:
-            pass
-        else:
-            raise acos_errors.Exists
-
-        return self._set(name, ip_address, arp_disable, description, vrid, virtual_server_templates,
-                         template_virtual_server, **kwargs)
+               virtual_server_templates=None, template_virtual_server=None,
+               port_list=None, max_retries=None, timeout=None, status=None, **kwargs):
+        params = self._set(name, ip_address, arp_disable=arp_disable, description=description,
+                           vrid=vrid, virtual_server_templates=virtual_server_templates,
+                           template_virtual_server=template_virtual_server,
+                           port_list=port_list, status=status, **kwargs)
+        return self._post(self.url_prefix, params, max_retries=max_retries, timeout=timeout, axapi_args=kwargs)
 
     def update(self, name, ip_address=None, arp_disable=False, description=None, vrid=None,
-               virtual_server_templates=None, template_virtual_server=None, **kwargs):
-        return self._set(name, ip_address, arp_disable, description, vrid, virtual_server_templates,
-                         template_virtual_server, update=True, **kwargs)
+               virtual_server_templates=None, template_virtual_server=None,
+               port_list=None, max_retries=None, timeout=None, status=None, **kwargs):
+        params = self._set(name, ip_address, arp_disable=arp_disable, description=description,
+                           vrid=vrid, virtual_server_templates=virtual_server_templates,
+                           template_virtual_server=template_virtual_server,
+                           port_list=port_list, status=status, **kwargs)
+        return self._post(self.url_prefix + name, params, max_retries=max_retries, timeout=timeout,
+                          axapi_args=kwargs)
+
+    def replace(self, name, ip_address=None, arp_disable=False, description=None, vrid=None,
+                virtual_server_templates=None, template_virtual_server=None,
+                port_list=None, max_retries=None, timeout=None, status=None, **kwargs):
+        params = self._set(name, ip_address, arp_disable=arp_disable, description=description,
+                           vrid=vrid, virtual_server_templates=virtual_server_templates,
+                           template_virtual_server=template_virtual_server,
+                           port_list=port_list, status=status, **kwargs)
+        return self._put(self.url_prefix + name, params, max_retries=max_retries, timeout=timeout,
+                         axapi_args=kwargs)
 
     def delete(self, name):
         return self._delete(self.url_prefix + name)
 
-    def stats(self, name='', **kwargs):
-        resp = self._get(self.url_prefix + name + '/port/stats', **kwargs)
+    def stats(self, name='', max_retries=None, timeout=None, **kwargs):
+        resp = self._get(self.url_prefix + name + '/port/stats', max_retries=max_retries,
+                         timeout=timeout, axapi_args=kwargs)
         return resp
 
-    def oper(self, name='', **kwargs):
-        resp = self._get(self.url_prefix + name + '/oper', **kwargs)
+    def oper(self, name='', max_retries=None, timeout=None, **kwargs):
+        resp = self._get(self.url_prefix + name + '/oper', max_retries=max_retries,
+                         timeout=timeout, axapi_args=kwargs)
         return resp
